# -*- coding: utf-8 -*-

"""
@Project : hertz_packet 
@File    : log.py
@Date    : 2023/5/30 17:45:45
@Author  : zhchen
@Desc    : 
"""
from notice.log import Logger

logger = Logger().get_logger()
logger.info("hhh")
